==> ingdao-0.0.6.tar.gz: lib/dataflow/field/dfbasefield.dart <==
import 'package:meta/meta.dart';
import '../entity/dfbaseentity.dart';
import '../field/dffieldtype.dart';
import '../control/dfconverter.dart';
import 'package:object_mapper/object_mapper.dart';

abstract class DfBaseField {

  DfBaseEntity entity;
  String name;
  bool displayOnly = false;
  DfFieldType fieldType;
  var value;
  Function getObjectValue;
  Function setObjectValue;

  DfBaseField({@required this.entity, @required this.name, @required this.fieldType, this.displayOnly, this.setObjectValue, this.getObjectValue, this.value}) {
    if (fieldType != null && fieldType.validator != null)
      fieldType.validator.field = this;    
  }

  String valueAsString() {
    return value;
  }

  DateTime valueAsDateTime() {
    return value;
  }

  bool valueAsBool() {
    return value;
  }

  int valueAsInt() {
    return value;
  }

  double valueAsDouble() {
    return value;
  }

  Transformable getTransform() {
    if (fieldType != null) {
      if (fieldType.isDateTime) {
        print("StrDateTimeTransform for field $name");
        return StrDateTimeTransform();
      }
      else if (fieldType.isBoolean) {
        print("IntBoolTransform for field $name");
        return IntBoolTransform();
      }
    }
    return null;
  }

  setValueFromQueryResult(Map<String,dynamic> dict);

  @override
  bool operator ==(Object other) => other is DfBaseField && other.name == name && other.entity.entityName == entity.entityName;

  @override
  int get hashCode => name.hashCode + entity.entityName.hashCode;  

}

==> ingdao-0.0.19.tar.gz: lib/dataflow/field/dfbasefield.dart <==
import 'package:meta/meta.dart';
import '../entity/dfbaseentity.dart';
import '../field/dffieldtype.dart';
import '../control/dfconverter.dart';
import 'package:object_mapper/object_mapper.dart';

enum AggregateType {
  count,
  sum
}

extension AggregateTypeExtension on AggregateType {

  String get name {
    switch (this) {
      case AggregateType.count:
        return 'COUNT';
      case AggregateType.sum:
        return 'SUM';
      default:
        return null;
    }
  }

  String desp() {
    return this.name;
  }
}

abstract class DfBaseField {

  DfBaseEntity entity;
  String name;
  bool displayOnly = false;
  DfFieldType fieldType;
  var value;
  Function getObjectValue;
  Function setObjectValue;

  AggregateType aggregateType;

  DfBaseField({@required this.entity, @required this.name, @required this.fieldType, this.displayOnly, this.setObjectValue, this.getObjectValue, this.value}) {
    if (fieldType != null && fieldType.validator != null)
      fieldType.validator.field = this;    
  }

  String valueAsString() {
    return value;
  }

  DateTime valueAsDateTime() {
    return value;
  }

  bool valueAsBool() {
    return value;
  }

  int valueAsInt() {
    return value;
  }

  double valueAsDouble() {
    return value;
  }

  Transformable getTransform() {
    if (fieldType != null) {
      if (fieldType.isDateTime) {
        //print("StrDateTimeTransform for field $name");
        return StrDateTimeTransform();
      }
      else if (fieldType.isBoolean) {
        //print("IntBoolTransform for field $name");
        return IntBoolTransform();
      }
    }
    return null;
  }

  setValueFromQueryResult(Map<String,dynamic> dict);

  @override
  bool operator ==(Object other) => other is DfBaseField && other.name == name && other.entity.entityName == entity.entityName;

  @override
  int get hashCode => name.hashCode + entity.entityName.hashCode;  

}
